@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.034001";
+$VERSION = "5.036000";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.34.1) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.36.0) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.34.1
-    or die sprintf "%s: Perl lib version (5.34.1) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.36.0
+    or die sprintf "%s: Perl lib version (5.36.0) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -84,7 +84,7 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/usr/pkg/lib/perl5/5.34.0/x86_64-linux-thread-multi',
+    archlibexp => '/usr/pkg/lib/perl5/5.36.0/x86_64-linux-thread-multi',
     archname => 'x86_64-linux-thread-multi',
     cc => 'cc',
     d_readlink => 'define',
@@ -98,14 +98,14 @@ tie %Config, 'Config', {
     ldlibpthname => 'LD_LIBRARY_PATH',
     libpth => '/lib/../lib64 /usr/lib/../lib64 /lib /usr/lib /usr/local/lib /lib64 /usr/lib64',
     osname => 'linux',
-    osvers => '5.19.3-arch1-1',
+    osvers => '6.0.0',
     path_sep => ':',
-    privlibexp => '/usr/pkg/lib/perl5/5.34.0',
+    privlibexp => '/usr/pkg/lib/perl5/5.36.0',
     scriptdir => '/usr/pkg/lib/perl5/bin',
-    sitearchexp => '/usr/pkg/lib/perl5/site_perl/5.34.0/x86_64-linux-thread-multi',
-    sitelibexp => '/usr/pkg/lib/perl5/site_perl/5.34.0',
+    sitearchexp => '/usr/pkg/lib/perl5/site_perl/5.36.0/x86_64-linux-thread-multi',
+    sitelibexp => '/usr/pkg/lib/perl5/site_perl/5.36.0',
     so => 'so',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.34.1',
+    version => '5.36.0',
 };
